@@ -1,4 +1,6 @@
 /*-------------------------------------------------------------------------------
+  Copyright (c) 2024 GRF Contributors.
+
   This file is part of generalized random forest (grf).
 
   grf is free software: you can redistribute it and/or modify
@@ -14,7 +16,7 @@
   You should have received a copy of the GNU General Public License
   along with grf. If not, see <http://www.gnu.org/licenses/>.
  #-------------------------------------------------------------------------------*/
- 
+
 #include <thread>
 #include <stdexcept>
 
@@ -35,13 +37,15 @@ ForestOptions::ForestOptions(uint num_trees,
                              double imbalance_penalty,
                              uint num_threads,
                              uint random_seed,
+                             bool legacy_seed,
                              const std::vector<size_t>& sample_clusters,
                              uint samples_per_cluster):
     ci_group_size(ci_group_size),
     sample_fraction(sample_fraction),
     tree_options(mtry, min_node_size, honesty, honesty_fraction, honesty_prune_leaves, alpha, imbalance_penalty),
     sampling_options(samples_per_cluster, sample_clusters),
-    random_seed(random_seed) {
+    random_seed(random_seed),
+    legacy_seed(legacy_seed) {
 
   this->num_threads = validate_num_threads(num_threads);
 
@@ -83,6 +87,10 @@ uint ForestOptions::get_random_seed() const {
   return random_seed;
 }
 
+bool ForestOptions::get_legacy_seed() const {
+  return legacy_seed;
+}
+
 uint ForestOptions::validate_num_threads(uint num_threads) {
   if (num_threads == DEFAULT_NUM_THREADS) {
     return std::thread::hardware_concurrency();
