@@ -46,7 +46,7 @@ ForestTrainer ll_regression_trainer(double split_lambda,
                                    size_t ll_split_cutoff,
                                    std::vector<size_t> ll_split_variables);
 
-ForestTrainer survival_trainer();
+ForestTrainer survival_trainer(bool fast_logrank);
 
 ForestTrainer causal_survival_trainer(bool stabilize_splits);
 
